==> icons-vue-0.3.0.tgz: package/lib/help--filled/16.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_HelpFilled16 = {
  name: 'HelpFilled16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 16 16',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = __chunk_1._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M8,12.5c-0.4,0-0.8-0.3-0.8-0.8S7.6,11,8,11c0.4,0,0.8,0.3,0.8,0.8\tS8.4,12.5,8,12.5z M8.6,8.6v1.2H7.4V7.5h1.1c0.7,0,1.2-0.6,1.1-1.3c0-0.6-0.5-1.1-1.1-1.1H7.8c-0.7,0-1.2,0.5-1.2,1.2v0.3H5.4V6.3\tC5.4,5,6.5,4,7.8,4h0.7c1.3,0,2.3,1.1,2.2,2.4C10.7,7.6,9.8,8.6,8.6,8.6L8.6,8.6z"
      }
    }), children]);
  }
};

module.exports = virtual_HelpFilled16;

==> icons-vue-0.6.0.tgz: package/lib/help--filled/16.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_HelpFilled16 = {
  name: 'HelpFilled16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 16 16',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M8,1C4.1,1,1,4.1,1,8s3.1,7,7,7s7-3.1,7-7S11.9,1,8,1z M8,12.5c-0.4,0-0.8-0.3-0.8-0.8S7.6,11,8,11c0.4,0,0.8,0.3,0.8,0.8\tS8.4,12.5,8,12.5z M8.6,8.6v1.2H7.4V7.5h1.1c0.7,0,1.2-0.6,1.1-1.3c0-0.6-0.5-1.1-1.1-1.1H7.8c-0.7,0-1.2,0.5-1.2,1.2v0.3H5.4V6.3\tC5.4,5,6.5,4,7.8,4h0.7c1.3,0,2.3,1.1,2.2,2.4C10.7,7.6,9.8,8.6,8.6,8.6L8.6,8.6z"
      }
    }), children]);
  }
};

module.exports = virtual_HelpFilled16;
